@@ -846,3 +846,85 @@ fitEllipse <- function(points){
   attr(fittedEllipse, "RSS") <- fit[["RSS"]]
   fittedEllipse
 }
+
+#' @title Maximum area ellipse inscribed in a convex polygon
+#' @description Computes the ellipse inscribed in a convex polygon with
+#'   maximum area.
+#'
+#' @param points the vertices of the polygon in a two-columns matrix; their
+#'   order has no importance, since the procedure takes the convex hull of
+#'   these points (and does not check the convexity)
+#' @param verbose argument passed to \code{\link[CVXR:psolve]{psolve}}
+#'
+#' @return An \code{Ellipse} object. The status of the optimization problem
+#'   is given as an attribute of this ellipse. A warning is thrown if it is
+#'   not optimal.
+#' @export
+#' @seealso \code{\link{maxAreaInscribedCircle}}
+#' @importFrom rcdd makeV scdd
+#' @importFrom CVXR Variable Minimize log_det norm2 Problem psolve
+#' @examples
+#' hexagon <- rbind(
+#'   c(-1.7, -1),
+#'   c(-1.4, 0.4),
+#'   c(0.3, 1.3),
+#'   c(1.7, 0.6),
+#'   c(1.3, -0.3),
+#'   c(-0.4, -1.8)
+#' )
+#' opar <- par(mar = c(2, 2, 1, 1))
+#' plot(NULL, xlim=c(-2, 2), ylim=c(-2, 2), xlab = NA, ylab = NA, asp = 1)
+#' points(hexagon, pch = 19)
+#' polygon(hexagon)
+#' ell <- maxAreaInscribedEllipse(hexagon)
+#' draw(ell, col = "yellow2", border = "blue", lwd = 2)
+#' par(opar)
+#' # check optimization status:
+#' attr(ell, "status")
+maxAreaInscribedEllipse <- function(points, verbose = FALSE) {
+  if(!is.matrix(points) || !is.numeric(points)){
+    stop("The `points` argument must be a numeric matrix.", call. = TRUE)
+  }
+  if(ncol(points) != 2L){
+    stop("The `points` matrix must have two columns.", call. = TRUE)
+  }
+  if(nrow(points) < 3L){
+    stop("The `points` matrix must have at least three rows.", call. = TRUE)
+  }
+  if(any(is.na(points))){
+    stop("Points with missing values are not allowed.", call. = TRUE)
+  }
+  # linear inequalities
+  V <- makeV(points)
+  H <- scdd(V)[["output"]]
+  A <- - H[, -c(1L, 2L)]
+  b <- H[, 2L]
+  # problem variables
+  Bvar <- Variable(2L, 2L, symmetric = TRUE)
+  dvar <- Variable(2L)
+  # objective
+  objective <- Minimize(-log_det(Bvar))
+  #constraints
+  constraints <- list()
+  for(i in 1L:nrow(A)) {
+    constraints <- append(
+      constraints, list(norm2(Bvar %*% A[i, ]) + sum(A[i, ]*dvar) <= b[i])
+    )
+  }
+  # solve the problem
+  program <- Problem(objective, constraints)
+  solution <- psolve(program, solver = "SCS", verbose = verbose)
+  status <- solution[["status"]]
+  if(status != "optimal") {
+    warning("Non-optimal solution.")
+  }
+  # get solutions
+  B <- solution$getValue(Bvar)
+  d <- c(solution$getValue(dvar))
+  # get ellipse
+  aff <- Affine$new(B, d)
+  unitcircle <- CircleOA(c(0, 0), c(1, 0))
+  ell <- aff$transformEllipse(unitcircle)
+  attr(ell, "status") <- status
+  ell
+}
